# REL08: How do you implement change?

## References

- [AWS REL08](https://docs.aws.amazon.com/wellarchitected/latest/framework/rel-08.html)

## Date

2025-11-27

## Focus Area

Change Management

## Tổng quan

REL08 tập trung vào implementing changes safely.

## Best Practices

### REL08-BP01: Use runbooks for standard activities
Documented procedures.

### REL08-BP02: Integrate functional testing as part of deployment
Test in pipeline.

### REL08-BP03: Integrate resiliency testing as part of deployment
Chaos testing.

### REL08-BP04: Deploy using immutable infrastructure
Immutable deployments.

### REL08-BP05: Deploy changes with automation
Automated deployments.

## Checklist

- [ ] Runbooks for changes
- [ ] Tests in deployment pipeline
- [ ] Immutable infrastructure
- [ ] Automated deployments
